Message

Enum Message 

#[non_exhaustive]
pub enum Message<'a> { Hello(Hello), HelloAck(HelloAck<'a>), Refusal(Refusal<'a>), ScanRequest(ScanRequest<'a>), RangeRequest(RangeRequest), Batch(Batch<'a>), Unknown(Header), }
One record, decoded.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Hello(Hello)

See Hello.



HelloAck(HelloAck<'a>)

See HelloAck.



Refusal(Refusal<'a>)

See Refusal.



ScanRequest(ScanRequest<'a>)



RangeRequest(RangeRequest)



Batch(Batch<'a>)

See Batch.



Unknown(Header)

A record this build has no code for. It has already been stepped over, so a reader that gets one of these can carry on to the next record.

Tuple Fields

0: Header

What was on the front of the record that could not be handled.