pub struct Nodes<'a> { /* private fields */ }Expand description
A list of Nodes, still in its encoded form.
Implementations
Sourceimpl<'a> Nodes<'a>
impl<'a> Nodes<'a>
Sourcepub fn from_bytes(raw: &'a [u8]) -> Result<Self>
pub fn from_bytes(raw: &'a [u8]) -> Result<Self>
Wraps the encoded form.
Errors
Returns Error::Malformed if the length is not a whole number of nodes.